@@ -22,7 +22,7 @@ type Namespace struct {
 func NewNamespace() *Namespace {
 	return &Namespace{
 		Active:    defaultNS,
-		Favorites: []string{defaultNS},
+		Favorites: []string{"default"},
 	}
 }
 
@@ -32,7 +32,7 @@ func (n *Namespace) Validate(c client.Connection, ks KubeSettings) {
 	if err != nil {
 		return
 	}
-	nn := ks.NamespaceNames(nns)
+	nn := client.NamespaceNames(nns)
 	if !n.isAllNamespaces() && !InList(nn, n.Active) {
 		log.Error().Msgf("[Config] Validation error active namespace %q does not exists", n.Active)
 	}
